/**
  *  \file game/reset.h
  *  \brief GReset: Resetting Stuff
  *
  *  (c) 2001-2016 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GAME_RESET_H
#define PCC_V2_GAME_RESET_H

#include "game/objlist.h"
#include "game/coord.h"

class GGameTurn;
class GCommandContainer;

class GReset {
 public:
    enum {
        ResetMissions = 1,
        ResetCargo    = 2
    };

    GReset();
    ~GReset();

    void addLocation(GGameTurn& trn, GPoint pt);

    void setMode(int mode);
    int getMode() const;

    bool isReady() const;
    void commit();

    const GObjectList& getObjects() const;

 private:
    void removeCommands(int id, bool ship);

    int mode;
    GObjectList dat_objects;
    GObjectList dis_objects;
    std::vector<GCommandContainer*> commands;
};

/******************************** Inlines ********************************/

/** Set reset mode.
    \param mode New mode, combination of ResetXxx */
inline void
GReset::setMode(int mode)
{
    this->mode = mode;
}

/** Get reset mode. */
inline int
GReset::getMode() const
{
    return mode;
}

/** Get list of objects. */
inline const GObjectList&
GReset::getObjects() const
{
    return dat_objects;
}

#endif
